#!/bin/bash

# COPYRIGHT 2003-2014, EMULEX CORPORATION                               
# 3333 Susan St., Costa Mesa, CA 92626                                  
#                                                                         
# All rights reserved.  This computer program and related documentation 
# is protected by copyright  and distributed under licenses restricting 
# its use,  copying,  distribution  and decompilation.    This computer 
# program  and its  documentation  are CONFIDENTIAL  and a TRADE SECRET 
# of EMULEX CORPORATION.   The receipt or  possession of  this  program 
# or its documentation does not  convey rights to reproduce or disclose 
# its  contents,  or to  manufacture, use, or sell anything that it may 
# describe, in whole or in part,  without the specific  written consent 
# of  EMULEX CORPORATION.   Any reproduction  of  this program  without 
# the express  written  consent  of EMULEX  CORPORATION  is a violation 
# of the  copyright laws  and may  subject you to  criminal prosecution.

#######################################################################
#                           linddcfg.sh                               #
# This script executes linddcfg with the requested arguments. This    #
# script also installs the MILI daemon and preserves the daemons's    #
# initial state.                                                      #
#                                                                     #
#######################################################################

# Status vars
LPCFG_STATUS=0
SUCCESS=0
TRUE=1
FALSE=0
FIELD_ADMIN_RIGHTS_ERROR=15
FIELD_UNSUPPORTED_OS=23
FIELD_UNSUPPORTED_ARCH=24
FIELD_BIN_NOT_FOUND=25
BYPASS_MILI_INSTALL=0

# kit directory vars
CLU_OS=""
CLU_OS_FULL=""
CLU_ARCH=""
LPFC_OS=""
KIT_DIR=""


# lpcfg vars
LOAD_PATH="LD_LIBRARY_PATH=."
LPCFG_BIN="linddcfg"
CLU_LIBDFC="libdfc.so"
CLU_LIBMILI="libmili2.so"
ARGUMENTS=""

# driver vars
LPFC_DRIVER=""

# logfile
LOG_FILE="field_lpcfg.log"
LOG=""

# OCM daemons
ELX_DISCO_SCRIPT=/etc/init.d/elxdiscoveryd
ELX_HBAMGR_SCRIPT=/etc/init.d/elxhbamgrd
ELX_SNMP_SCRIPT=/etc/init.d/elxsnmpd
ELX_MILI_SCRIPT=/etc/init.d/elxmilid
INITIAL_MILI_STATUS=0
INITIAL_SNMP_STATUS=0
INITIAL_HBAMGR_STATUS=0
INITIAL_DISCO_STATUS=0

# Dell Update RollBack executable
UPDATE_ROLLBACK_BIN="UpdRollBack"



#####################################################################
#                                                                   #
# Function: is_root                                                 #
#                                                                   #
# Checks if this script is being run by root.                       #
#                                                                   #
#####################################################################
function is_root()
{
    USER=`whoami`
    if [ "$USER" != "root" ]; then
        echo "Not the root user! Exiting..."
        exit $FIELD_ADMIN_RIGHTS_ERROR
    fi
}


#####################################################################
#                                                                   #
# Function: log_message                                             #
#                                                                   #
# Print the strings passed as parameters to a log file.             #
#                                                                   #
#####################################################################
function log_message()
{
    local ECHO_OPTIONS
    
    if [ $# -eq 0 ] ; then
        echo "" >> "$LOG"
    elif [ -z "$1" ] ; then
        echo "" >> "$LOG"
    elif [ "$1" = "-init" ] ; then
        rm -f "$LOG"
        print_time "Start_time"
    else
        while [ -n "$1" ] ; do
            if [ "${1:0:1}" = "-" ] ; then
                ECHO_OPTIONS="${1}"
            else
                echo ${ECHO_OPTIONS} "$1" >> "$LOG"
            fi
            shift
        done
    fi
    return $SUCCESS
}


#####################################################################
#                                                                   #
# Function: print_time                                              #
#                                                                   #
# Prints the current time.                                          #
#                                                                   #
#                                                                   #
#####################################################################
function print_time()
{
    echo "[$1]" >> "$LOG"
    echo -e "$(date)\n" >> "$LOG"
}


#####################################################################
#                                                                   #
# Function: print_cli                                               #
#                                                                   #
# Prints the command line input.                                    #
#                                                                   #
#                                                                   #
#####################################################################
function print_cli()
{
    log_message "[print_cli]"
    log_message -e "$0 $ARGUMENTS\n"
}


#####################################################################
#                                                                   #
# Function: set_kit_path                                            #
#                                                                   #
# Sets the kit's directory path.                                    #
#                                                                   #
#####################################################################
function set_kit_path()
{
    DIRNAME=`dirname "$0"`
    KIT_DIR=$(cd "$DIRNAME" && pwd)
}


#####################################################################
#                                                                   #
# Function: init_log_file                                           #
#                                                                   #
# Initializes the log file.                                         #
#                                                                   #
#####################################################################
function init_log_file
{
    LOG="$KIT_DIR/$LOG_FILE"
    log_message -init
}


#####################################################################
#                                                                   #
# Function: set_dir_paths                                           #
#                                                                   #
# Sets the common and config diretory paths.                        #
#                                                                   #
#####################################################################
function set_dir_paths()
{
    log_message "[set_dir_paths]"
    LPCFG_PAYLOAD="$KIT_DIR/../../common/payload"
    LPCFG_CONFIG="$KIT_DIR"
    
    log_message "cp -r --preserve=all --remove-destination \"$LPCFG_PAYLOAD/\"* \"$KIT_DIR\" > /dev/null 2>&1"
    cp -r --preserve=all --remove-destination "$LPCFG_PAYLOAD/"* "$KIT_DIR" > /dev/null 2>&1
    
    LPCFG_PAYLOAD="$KIT_DIR"
    
    log_message "Payload dir = $LPCFG_PAYLOAD"
    log_message "Config dir  = $LPCFG_CONFIG"
    log_message "Kit dir     = $KIT_DIR"
    log_message ""
}


#####################################################################
#                                                                   #
# Function: log_script_dir_contents                                 #
#                                                                   #
# Log the contents of the execution script's directory.             #
#                                                                   #
#####################################################################
function log_script_dir_contents()
{
    log_message "[log_script_dir_contents]"
    log_message "ls -Rl \"$KIT_DIR\" >> \"$LOG\" 2>&1"
    ls -Rl "$KIT_DIR" >> "$LOG" 2>&1
    log_message ""
}


#####################################################################
#                                                                   #
# Function: determine_arch                                          #
#                                                                   #
# Determine the processor architecture.                             #
#                                                                   #
# NOTE: If an invalid architecture is detected this function will   #
#       terminate script execution.                                 #
#                                                                   #
#####################################################################
function determine_arch()
{
    log_message "[determine_arch]"
    CLU_ARCH=$(uname -m)
    case ${CLU_ARCH} in
        i[3456]86)
            CLU_ARCH=i386
            ARCH_STR=
            ;;
        
        x86_64)
            CLU_ARCH=x86_64
            ARCH_STR=_64
            ;;
        
        *)
            log_message "Unsupported architecture: $CLU_ARCH"
            log_message "Aborting execution."
            exit $FIELD_UNSUPPORTED_ARCH
            ;;
    esac
    
    log_message -e "CLU_ARCH = $CLU_ARCH\n"
}


#####################################################################
#                                                                   #
# Function: determine_distribution                                  #
#                                                                   #
# Determine the distribution.                                       #
#                                                                   #
# NOTE: If an invalid distribution is detected this function will   #
#       terminate script execution.                                 #
#                                                                   #
#####################################################################
function determine_distribution()
{
    log_message "[determine_distribution]"
    
    if [ -f /etc/redhat-release ]; then
        citrixos=`cat /etc/redhat-release | cut -d' ' -f1`
        if [ "$citrixos" = "XenServer" ];then
            citrix_major=`cat /etc/redhat-release | cut -d' ' -f3 | cut -d'.' -f1`
            citrix_minor=`cat /etc/redhat-release | cut -d' ' -f3 | cut -d'.' -f2`
            citrix_rev=`cat /etc/redhat-release | cut -d' ' -f3 | cut -d'.' -f3 | cut -d'-' -f1`
            CLU_OS_FULL="citrix-${citrix_major}.${citrix_minor}.${citrix_rev}"
            
            if [[ $citrix_major -eq 6 ]] && [[ $citrix_minor -eq 0 ]] && [[ $citrix_rev -ge 0 ]]; then
                CLU_OS="xenserver-6"
            elif [[ $citrix_major -eq 6 ]]; then
                CLU_OS="xenserver-6"
            else
                print_unsupported_kernel "Citrix XenServer"
            fi
        
        elif [ "$citrixos" = "CentOS" ];then
            CENTOS_RT="-f3"
            
            # Change the release token for CentOS 6.0
            centos=`cat /etc/redhat-release | grep 6.0 -q`
            if [ $? -eq 0 ]; then
                CENTOS_RT="-f4"
            fi
            
            rhel_major_version=`cat /etc/redhat-release | cut -d' ' ${CENTOS_RT} | cut -d. -f1`
            rhel_minor_version=`cat /etc/redhat-release | cut -d' ' ${CENTOS_RT} | cut -d. -f2`
            if [ "$rhel_major_version" -eq 5 ]; then
                if [ "$rhel_minor_version" -lt 5 ]; then
                    print_unsupported_kernel "CentOS 5"
                else
                    CLU_OS="rhel-5"
                    CLU_OS_FULL="rhel-5.${rhel_minor_version}"
                fi
            elif [ "$rhel_major_version" -eq 6 ]; then
                #if [ "$rhel_minor_version" -lt 1 ]; then
                #    print_unsupported_kernel "CentOS 6"
                #else
                    CLU_OS="rhel-6"
                    CLU_OS_FULL="rhel-6.${rhel_minor_version}"
                #fi
            elif [ "$rhel_major_version" -eq 7 ]; then
                CLU_OS="rhel-7"
                CLU_OS_FULL="rhel-7.${rhel_minor_version}"
            else
                print_unsupported_kernel "CentOS"
            fi
        
        else
            rhel_major_version=`cat /etc/redhat-release | cut -d' ' -f7 | cut -d. -f1`
            rhel_minor_version=`cat /etc/redhat-release | cut -d' ' -f7 | cut -d. -f2`
            if [ "$rhel_major_version" -eq 5 ]; then
                if [ "$rhel_minor_version" -lt 5 ]; then
                    print_unsupported_kernel "Red Hat Enterprise Linux Server 5"
                else
                    CLU_OS="rhel-5"
                    CLU_OS_FULL="rhel-5.${rhel_minor_version}"
                fi
            elif [ "$rhel_major_version" -eq 6 ]; then
                #if [ "$rhel_minor_version" -lt 1 ]; then
                #    print_unsupported_kernel "Red Hat Enterprise Linux Server 6"
                #else
                    CLU_OS="rhel-6"
                    CLU_OS_FULL="rhel-6.${rhel_minor_version}"
                #fi
            elif [ "$rhel_major_version" -eq 7 ]; then
                CLU_OS="rhel-7"
                CLU_OS_FULL="rhel-7.${rhel_minor_version}"
            else
                print_unsupported_kernel "Red Hat Enterprise Linux Server"
            fi
        fi
    
    elif [ -f /etc/SuSE-release ]; then
        sles_major_version=`cat /etc/SuSE-release | grep VERSION | awk '{ print $3 }'`
        sles_minor_version=`cat /etc/SuSE-release | grep PATCHLEVEL | awk '{ print $3 }'`
        if [ "$sles_major_version" -eq 11 ]; then
            if [ "$sles_minor_version" -lt 1 ]; then
                print_unsupported_kernel "SuSE Linux Enterprise Server 11"
            else
                CLU_OS="sles-11"
                CLU_OS_FULL="sles-11.${sles_minor_version}"
            fi
        elif [ "$sles_major_version" -eq 12 ]; then
            CLU_OS="sles-12"
            CLU_OS_FULL="sles-12.${sles_minor_version}"
        else
            print_unsupported_kernel "SuSE Linux Enterprise Server"
        fi
    fi
    
    if [ ! -d "${KIT_DIR}/${CLU_ARCH}/${CLU_OS}" ]; then
        log_message "Could not find installation directory: \"${KIT_DIR}/${CLU_ARCH}/${CLU_OS}\""
        log_message "Aborting execution."
        exit $FIELD_BIN_NOT_FOUND
    fi
    
    log_message "APPS DIR        = ${KIT_DIR}/${CLU_ARCH}/${CLU_OS}"
    log_message "CLU_OS_FULL     = $CLU_OS_FULL"
    log_message ""
}


#####################################################################
#                                                                   #
# Function: log_installed_net_drivers                               #
#                                                                   #
# Log installed network drivers.                                    #
#                                                                   #
#####################################################################
function log_installed_net_drivers()
{
    log_message "[log_installed_net_drivers]"
    which ethtool > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        ETH_DEVICES=`ls /sys/class/net`
        if [ "$ETH_DEVICES" != "" ]; then
            for eth in $ETH_DEVICES
            do
                ETHTOOL_DEV=`ethtool -i $eth 2>&1`
                log_message "$eth:"
                log_message "$ETHTOOL_DEV"
                log_message ""
            done
        else
            log_message "No network interfaces found"
        fi
    else
        log_message "ethtool is not available"
    fi
    log_message ""
}


#####################################################################
#                                                                   #
# Function: log_installed_hbas                                      #
#                                                                   #
# Log installed HBAs.                                               #
#                                                                   #
#####################################################################
function log_installed_hbas()
{
    log_message "[log_installed_hbas]"
    which lspci > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        ELX_HBAS=`lspci | grep Emulex`
        log_message "lspci | grep Emulex"
        log_message "$ELX_HBAS"
        log_message ""
    
        ELX_UCNAS=`lspci -d 19a2:*`
        log_message "lspci -d 19a2:*"
        log_message "$ELX_UCNAS"
    else
        log_message "lspci is not available"
    fi
    log_message ""
}


#####################################################################
#                                                                   #
# Function: print_unsupported_kernel                                #
#                                                                   #
# Print an error messsage and exit.                                 #
#                                                                   #
# NOTE: This function will terminate script execution.              #
#                                                                   #
#####################################################################
function print_unsupported_kernel()
{
    distro=$1
    kernel=$(uname -r)
    log_message "Unsupported $distro Kernel = $kernel"
    log_message "Aborting execution."
    log_message ""
    exit $FIELD_UNSUPPORTED_OS
}


#####################################################################
#                                                                   #
# Function: check_deps                                              #
#                                                                   #
# Determines if the UpdRollBack and linddcfg executables have any   #
# missing dependencies.                                             #
#                                                                   #
#                                                                   #
#####################################################################
function check_deps()
{
    log_message "[check_deps]"
    
    if [ -f ${KIT_DIR}/${UPDATE_ROLLBACK_BIN} ]; then
        log_message "Checking UpdRollBack dependencies:"    
        log_message "ldd ${KIT_DIR}/${UPDATE_ROLLBACK_BIN} | grep \"not found\""
        DEP_LIST=`ldd ${KIT_DIR}/${UPDATE_ROLLBACK_BIN} | grep "not found"`
        
        if [ -z "$DEP_LIST" ]; then
            log_message "${UPDATE_ROLLBACK_BIN} does not have any missing dependencies"
        else
            log_message "WARNING: ${UPDATE_ROLLBACK_BIN} has missing dependencies"
        fi
    fi
    
    log_message ""
    log_message "Checking $LPCFG_BIN dependencies:"
    log_message "ldd ${KIT_DIR}/${CLU_ARCH}/${CLU_OS}/${LPCFG_BIN} | grep \"not found\""
    DEP_LIST=`ldd ${KIT_DIR}/${CLU_ARCH}/${CLU_OS}/${LPCFG_BIN} | grep "not found"`
    if [ -z "$DEP_LIST" ]; then
        log_message "${LPCFG_BIN} does not have any missing dependencies"
    else
        MISSING_DEPS=""
        DEP_LIST=`ldd ${KIT_DIR}/${CLU_ARCH}/${CLU_OS}/${LPCFG_BIN} | grep "not found" | cut -d ' ' -f1`
        for dep in $DEP_LIST
        do
            log_message "missing dependency = $dep"
            LIBDFC_DEP=`echo $dep | grep $CLU_LIBDFC`
            LIBMILI_DEP=`echo $dep | grep $CLU_LIBMILI`
            
            # LIBDFC and LIBMILI are included in the kit.
            if [ -n "$LIBDFC_DEP" ]; then
                log_message "Skipping $CLU_LIBDFC dependency   - $CLU_LIBDFC is provided by the ddcfg kit..."
            elif [ -n "$LIBMILI_DEP" ]; then
                log_message "Skipping $CLU_LIBMILI dependency - $CLU_LIBMILI is provided by the ddcfg kit..."
            else
                MISSING_DEPS="$dep $MISSING_DEPS"
            fi
        done
        
        if [ -z "$MISSING_DEPS" ]; then
            log_message "$LPCFG_BIN does not have any missing dependencies"
        else
            log_message "WARNING: $LPCFG_BIN is missing the following dependencies:"
            log_message "$MISSING_DEPS"
        fi
    fi
    
    log_message ""
    check_clu_lib_dep $CLU_LIBDFC
    log_message ""
    check_clu_lib_dep $CLU_LIBMILI
    log_message ""
}


function check_clu_lib_dep()
{
    log_message "[check_clu_lib_dep]"
    CLU_LIB=$1
    log_message "Checking $CLU_LIB dependencies:"
    log_message "ldd ${KIT_DIR}/${CLU_ARCH}/${CLU_OS}/${CLU_LIB} | grep \"not found\""
    MISSING_DEPS=`ldd ${KIT_DIR}/${CLU_ARCH}/${CLU_OS}/${CLU_LIB} | grep "not found"`
    if [ -z "$MISSING_DEPS" ]; then
        log_message "$CLU_LIB does not have any missing dependencies"
    else
        log_message "WARNING: $CLU_LIB is missing the following dependencies:"
        log_message "$MISSING_DEPS"
    fi
}


#####################################################################
#                                                                   #
# Function: get_daemons_status                                      #
#                                                                   #
# Determines the initial status of the OCM daemons.                 #
#                                                                   #
#####################################################################
function get_daemons_status()
{
    log_message "[get_daemons_status]"
    
    if [ $BYPASS_MILI_INSTALL -eq $TRUE ]; then
        log_message -e "Bypassing stopping the daemons!\n"
        return 0
    fi

    ps -ef | grep elxdiscoveryd | grep -v grep > /dev/null
    if [ $? -eq $SUCCESS ]; then
        INITIAL_DISCO_STATUS=$TRUE
        log_message "Stopping elxdiscoveryd"
        log_message "$ELX_DISCO_SCRIPT stop >> \"$LOG\" 2>&1"
        $ELX_DISCO_SCRIPT stop >> "$LOG" 2>&1
    fi
    
    ps -ef | grep elxhbamgrd | grep -v grep > /dev/null
    if [ $? -eq $SUCCESS ]; then
        INITIAL_HBAMGR_STATUS=$TRUE
        log_message "Stopping elxhbamgrd"
        log_message "$ELX_HBAMGR_SCRIPT stop >> \"$LOG\" 2>&1"
        $ELX_HBAMGR_SCRIPT stop >> "$LOG" 2>&1
    fi
    
    ps -ef | grep elxsnmpd | grep -v grep > /dev/null
    if [ $? -eq $SUCCESS ]; then
        INITIAL_SNMP_STATUS=$TRUE
        log_message "Stopping elxsnmpd"
        log_message "$ELX_SNMP_SCRIPT stop >> \"$LOG\" 2>&1"
        $ELX_SNMP_SCRIPT stop >> "$LOG" 2>&1
    fi
    
    ps -ef | grep mili2d | grep -v grep > /dev/null
    if [ $? -eq $SUCCESS ]; then
        INITIAL_MILI_STATUS=$TRUE
        log_message "Stopping elxmilid"
        log_message "$ELX_MILI_SCRIPT stop >> \"$LOG\" 2>&1"
        $ELX_MILI_SCRIPT stop >> "$LOG" 2>&1
    fi
    
    log_message "INITIAL_DISCO_STATUS  = $INITIAL_DISCO_STATUS"
    log_message "INITIAL_HBAMGR_STATUS = $INITIAL_HBAMGR_STATUS"
    log_message "INITIAL_SNMP_STATUS   = $INITIAL_SNMP_STATUS"
    log_message "INITIAL_MILI_STATUS   = $INITIAL_MILI_STATUS"
    log_message ""
}


#####################################################################
#                                                                   #
# Function: restore_daemons_status                                  #
#                                                                   #
# Restores the initial status of the OCM daemons.                   #
#                                                                   #
#####################################################################
function restore_daemons_status()
{
    log_message "[restore_daemons_status]"
    
    if [ $INITIAL_MILI_STATUS -eq $TRUE ]; then
        log_message "$ELX_MILI_SCRIPT start >> \"$LOG\" 2>&1"
        $ELX_MILI_SCRIPT start >> "$LOG" 2>&1
    fi
    if [ $INITIAL_SNMP_STATUS -eq $TRUE ]; then
        log_message "$ELX_SNMP_SCRIPT start >> \"$LOG\" 2>&1"
        $ELX_SNMP_SCRIPT start >> "$LOG" 2>&1
    fi
    if [ $INITIAL_HBAMGR_STATUS -eq $TRUE ]; then
        log_message "$ELX_HBAMGR_SCRIPT start >> \"$LOG\" 2>&1"
        $ELX_HBAMGR_SCRIPT start >> "$LOG" 2>&1
    fi
    if [ $INITIAL_DISCO_STATUS -eq $TRUE ]; then
        log_message "$ELX_DISCO_SCRIPT start >> \"$LOG\" 2>&1"
        $ELX_DISCO_SCRIPT start >> "$LOG" 2>&1
    fi
    
    log_message ""
}


#####################################################################
#                                                                   #
# Function: install_milid                                           #
#                                                                   #
# Installs the MILI daemon.                                         #
#                                                                   #
# Returns:                                                          #
#         0 -- Successfully started the MILI daemon.                #
#         1 -- Error in starting the MILI daemon.                   #
#                                                                   #
#####################################################################
function install_milid()
{
    log_message "[install_milid]"
    current_dir=$(pwd)
       
    log_message "Starting MILI daemon..."
    log_message "cd \"${KIT_DIR}/${CLU_ARCH}/${CLU_OS}\""
    cd "${KIT_DIR}/${CLU_ARCH}/${CLU_OS}"
    
    log_message "./elxmilid start >> \"$LOG\" 2>&1"
    ./elxmilid start >> "$LOG" 2>&1
    
    if [ $? -ne $SUCCESS ]; then
        log_message "Warning: elxmilid failed to start!"
    fi
    
    cd "$current_dir"
    log_message ""
}


#####################################################################
#                                                                   #
# Function: uninstall_milid                                         #
#                                                                   #
# Uninstalls the MILI daemon.                                       #
#                                                                   #
# Returns:                                                          #
#         0 -- Successfully stopped and removed the MILI daemon.    #
#         1 -- Error in removing the MILI daemon.                   #
#                                                                   #
#####################################################################
function uninstall_milid()
{
    log_message "[uninstall_milid]"
    current_dir=$(pwd)
    
    log_message "Stopping MILI daemon..."
    log_message "cd \"${KIT_DIR}/${CLU_ARCH}/${CLU_OS}\""
    cd "${KIT_DIR}/${CLU_ARCH}/${CLU_OS}"
    
    log_message "./elxmilid stop >> \"$LOG\" 2>&1"
    ./elxmilid stop >> "$LOG" 2>&1
    
    if [ $? -ne $SUCCESS ]; then
        log_message "Warning: elxmilid failed to stop!"
    fi
    
    cd "$current_dir"
    log_message ""
}


#####################################################################
#                                                                   #
# Function: check_for_help                                          #
#                                                                   #
# Checks an argument for the help (-h), version (-v), or            #
# verifyFW (-e) flag.                                               #
#                                                                   #
#                                                                   #
#####################################################################
function check_for_help()
{
    ARG=$1
    if [[ $ARG == "-h" ]] || \
       [[ $ARG == "-H" ]] || \
       [[ $ARG == "-v" ]] || \
       [[ $ARG == "-V" ]] || \
       [[ $ARG == "-e" ]] || \
       [[ $ARG == "-E" ]]; then
        BYPASS_MILI_INSTALL=$TRUE
    fi
}


#####################################################################
#                                                                   #
# Function: execute_lpcfg                                           #
#                                                                   #
# Execute lpcfg.                                                    #
#                                                                   #
# Returns:                                                          #
#         The linddcfg return code.                                 #
#                                                                   #
#####################################################################
function execute_lpcfg()
{
    log_message "[execute_lpcfg]"
    log_message "Executing: D_LIBRARY_PATH=\"$KIT_DIR/$CLU_ARCH/$CLU_OS\" \"$KIT_DIR/$CLU_ARCH/$CLU_OS/$LPCFG_BIN\" -p \"$LPCFG_PAYLOAD\" -c \"$LPCFG_CONFIG\" $ARGUMENTS "
    LD_LIBRARY_PATH="$KIT_DIR/$CLU_ARCH/$CLU_OS" "$KIT_DIR/$CLU_ARCH/$CLU_OS/$LPCFG_BIN" -p "$LPCFG_PAYLOAD" -c "$LPCFG_CONFIG" $ARGUMENTS
    LPCFG_STATUS=$?
    log_message ""
}


#####################################################################
#                                                                   #
# Begin script execution                                            #
#                                                                   #
# Save the command line arguments                                   #
#                                                                   #
#####################################################################
for i in $*
do
    #echo "i = $i"
    if [ -z "$ARGUMENTS" ]; then
        ARGUMENTS=$i
        check_for_help $i
    else
        ARGUMENTS="${ARGUMENTS} $i"
    fi
done
   

#
# Check for the root user.
#
is_root


#
# Set the kit path.
#
set_kit_path


#
# Initialize the log file.
#
init_log_file


#
# Write the command line input to the log file.
#
print_cli


#
# Set the payload and config directories.
#
set_dir_paths


#
# Log the contents of the execution script's directory.
#
log_script_dir_contents


#
# Determine if this architecture is supported
#
determine_arch


#
# Determine if this operating system is supported
#
determine_distribution


#
# Log installed network drivers
#
log_installed_net_drivers


#
# Log installed HBAs
#
log_installed_hbas


#
# Verify dependencies
#
check_deps


#
# Save the initial daemon status
#
get_daemons_status


#
# Check for the help and version args
#
if [ $BYPASS_MILI_INSTALL -eq $TRUE ]; then
    log_message "[Bypass_MILI_Install]"
    log_message -e "Skipping MILI installation!\n"
    execute_lpcfg
    print_time "Stop_time"
    exit $LPCFG_STATUS
fi


#
# Install and start MILID
#
install_milid


#
# Execute linddcfg command
#
execute_lpcfg


#
# Stop and remove MILID
#
uninstall_milid


#
# Restore the initial daemon status
#
restore_daemons_status


#
# Write the completion time
#
print_time "Stop_time"

exit $LPCFG_STATUS
